@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Content.pm,v 1.39 2005/10/01 22:10:57 fredo Exp $
+#   $Id: Content.pm,v 1.40 2005/10/19 19:04:43 fredo Exp $
 #
 #=======================================================================
 
@@ -47,7 +47,7 @@ BEGIN {
 
     @ISA = qw(PDF::API2::Basic::PDF::Dict);
     
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 1.39 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/10/01 22:10:57 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 1.40 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/10/19 19:04:43 $
 
 }
 
@@ -1818,14 +1818,14 @@ sub text
         $self->matrix_update($wd,0);
     }
     my $ulxy1=[$self->textpos2];
-    if($self->{' font'}->isvirtual)
-    {
+    #if($self->{' font'}->isvirtual)
+    #{
         $self->add($self->{' font'}->text($text,$self->{' fontsize'}));
-    } 
-    else 
-    {
-        $self->add($self->{' font'}->text($text),'Tj');
-    }
+    #} 
+    #else 
+    #{
+    #    $self->add($self->{' font'}->text($text),'Tj');
+    #}
     $wd=$self->advancewidth($text);
     $self->matrix_update($wd,0);
 
@@ -2163,6 +2163,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: Content.pm,v $
+    Revision 1.40  2005/10/19 19:04:43  fredo
+    added extended typographic text handling call
+
     Revision 1.39  2005/10/01 22:10:57  fredo
     added more docs for textlabel
 
